A function to pull cluster information from a domino object
Arguments
- dom
a domino object that has been created with
create_domino()- labels
a boolean for whether to return the cluster labels for each cell or the clusters used for inferring communication
Value
A vector containing either the names of the clusters used OR factors of the cluster label for each individual cell
See also
Accessor Functions:
dom_correlations(),
dom_counts(),
dom_database(),
dom_de(),
dom_info(),
dom_linkages(),
dom_network_items(),
dom_signaling(),
dom_tf_activation(),
dom_zscores()
Examples
example(build_domino, echo = FALSE)
cluster_names <- dom_clusters(pbmc_dom_built_tiny)
cell_cluster_label <- dom_clusters(pbmc_dom_built_tiny, labels = TRUE)