A function to pull the parameters used when running build_domino() from a domino object
Arguments
- dom
a domino object that has been created with
create_domino()
Value
A list containing booleans for whether the object has been created and built and a list of the
build parameters that were used in build_domino() to infer the signaling network
See also
Accessor Functions:
dom_clusters(),
dom_correlations(),
dom_counts(),
dom_database(),
dom_de(),
dom_linkages(),
dom_network_items(),
dom_signaling(),
dom_tf_activation(),
dom_zscores()
Examples
example(build_domino, echo = FALSE)
build_details <- dom_info(pbmc_dom_built_tiny)