A function to pull linkages from a domino object
Usage
dom_linkages(
dom,
link_type = c("complexes", "receptor-ligand", "tf-target", "tf-receptor", "receptor",
"incoming-ligand"),
by_cluster = FALSE
)Arguments
- dom
a domino object that has been created with
create_domino()- link_type
one value (out of "complexes", "receptor-ligand", "tf-target", "tf-receptor", "receptor", "incoming-ligand") used to select the desired type of linkage. Note that "receptor" and "incoming-ligand" are only available when by_cluster is set to TRUE.
- by_cluster
a boolean to indicate whether the linkages should be returned overall or by cluster
Value
A list containing linkages between some combination of receptors, ligands, transcription factors, and clusters
See also
Accessor Functions:
dom_clusters(),
dom_correlations(),
dom_counts(),
dom_database(),
dom_de(),
dom_info(),
dom_network_items(),
dom_signaling(),
dom_tf_activation(),
dom_zscores()
Examples
example(build_domino, echo = FALSE)
complexes <- dom_linkages(pbmc_dom_built_tiny, "complexes")
tf_rec_by_cluster <- dom_linkages(pbmc_dom_built_tiny, "tf-receptor", TRUE)