Access all features, receptors, or ligands present in a signaling network.
Source:R/utils.R
dom_network_items.RdThis function collates all of the features, receptors, or ligands found in a
signaling network anywhere in a list of clusters. This can be useful for
comparing signaling networks across two separate conditions. In order to run
this build_domino() must be run on the object previously.
Arguments
- dom
a domino object containing a signaling network (i.e.
build_domino()was run)- clusters
vector indicating clusters to collate network items from. If left as NULL then all clusters will be included.
- return
string indicating whether to collate "features", "receptors", or "ligands". If "all" then a list of all three will be returned.
Value
A vector containing all features, receptors, or ligands in the data set or a list containing all three.
See also
Accessor Functions:
dom_clusters(),
dom_correlations(),
dom_counts(),
dom_database(),
dom_de(),
dom_info(),
dom_linkages(),
dom_signaling(),
dom_tf_activation(),
dom_zscores()
Examples
example(build_domino, echo = FALSE)
monocyte_receptors <- dom_network_items(pbmc_dom_built_tiny, "CD14_monocyte", "receptors")
all_tfs <- dom_network_items(pbmc_dom_built_tiny, return = "features")