A function to pull transcription factor activation scores from a domino object
Arguments
- dom
a domino object that has been created with
create_domino()
Value
A matrix containing the transcription factor activation scores for each TF (row) by cell (column)
See also
Accessor Functions:
dom_clusters(),
dom_correlations(),
dom_counts(),
dom_database(),
dom_de(),
dom_info(),
dom_linkages(),
dom_network_items(),
dom_signaling(),
dom_zscores()
Examples
example(build_domino, echo = FALSE)
tf_activation <- dom_tf_activation(pbmc_dom_built_tiny)